@@ -34,26 +34,41 @@
     )
 {%- endmacro %}
 
-{% macro oracle_incremental_upsert(tmp_relation, target_relation, unique_key=none, statement_name="main") %}
-    {%- set dest_columns = adapter.get_columns_in_relation(target_relation) -%}
+{% macro oracle_incremental_upsert(tmp_relation, target_relation, dest_columns, unique_key=none, statement_name="main") %}
+    {%- set on_predicates = [] -%}
+    {%- set unique_key_list = [] -%}
     {%- set dest_cols_csv = dest_columns | map(attribute='name') | join(', ') -%}
+    {%- set update_columns = config.get('merge_update_columns', default=dest_columns | map(attribute='name'))-%}
 
-    {%- if unique_key is not none -%}
-    merge into {{ target_relation }} target
-      using {{ tmp_relation }} temp
-      on (temp.{{ unique_key }} = target.{{ unique_key }})
-    when matched then
-      update set
-      {% for col in dest_columns if col.name.upper() != unique_key.upper() -%}
-        target.{{ col.name }} = temp.{{ col.name }}{% if not loop.last %}, {% endif %}
-      {% endfor -%}
-    when not matched then
-      insert({{ dest_cols_csv }})
-      values(
-        {% for col in dest_columns -%}
-          temp.{{ col.name }}{% if not loop.last %}, {% endif %}
-        {% endfor -%}
-      )
+    {%- if unique_key -%}
+        {% if unique_key is sequence and unique_key is not mapping and unique_key is not string %}
+          {% for key in unique_key | unique %}
+                {% do unique_key_list.append(key.upper()) %}
+            {% endfor %}
+        {% else %}
+            {% do unique_key_list.append(unique_key.upper()) %}
+        {% endif %}
+        {% for key in unique_key_list %}
+            {% set this_key_match %}
+                    temp.{{ key }} = target.{{ key }}
+            {% endset %}
+            {% do on_predicates.append(this_key_match) %}
+        {% endfor %}
+        merge into {{ target_relation }} target
+          using {{ tmp_relation }} temp
+          on ({{ on_predicates | join(' AND ') }})
+        when matched then
+          update set
+          {% for col in update_columns if col.upper() not in unique_key_list -%}
+            target.{{ col }} = temp.{{ col }}{% if not loop.last %}, {% endif %}
+          {% endfor -%}
+        when not matched then
+          insert({{ dest_cols_csv }})
+          values(
+            {% for col in dest_columns -%}
+              temp.{{ col.name }}{% if not loop.last %}, {% endif %}
+            {% endfor -%}
+          )
     {%- else -%}
     insert into {{ target_relation }} ({{ dest_cols_csv }})
     (
